@@ -35,7 +35,7 @@ class Network3Medusa():
           "input": "show version",
           "output_format": "json"
         }}
-        response = requests.post(self.url,data=json.dumps(payload), headers=self.myheaders,auth=(self.username,self.password)).json()
+        response = requests.post(self.url,data=json.dumps(payload), headers=self.myheaders,auth=(self.username,self.password), verify=False).json()
         output = json.dumps(response, indent=4, sort_keys=True)
         return(output)
 
